@@ -368,10 +368,10 @@ class PsmPy:
                     df_preds_after_float, self.treatment, cl)])
             except:
                 data.append([cl, 'after', 0])
-        effect_size = pd.DataFrame(
+        self.effect_size = pd.DataFrame(
             data, columns=['Variable', 'matching', 'Effect Size'])
         sns.set_style("white")
-        sns_plot = sns.barplot(data=effect_size, y='Variable', x='Effect Size', hue='matching', palette=[
+        sns_plot = sns.barplot(data=self.effect_size, y='Variable', x='Effect Size', hue='matching', palette=[
                                before_color, after_color], orient='h')
         sns_plot.set(title=title)
         if save == True:
